Struct tracing_appender::non_blocking::ErrorCounter
source · [−]pub struct ErrorCounter(_);Expand description
Tracks the number of times a log line was dropped by the background thread.
If the non-blocking writer is not configured in lossy mode, the error count should always be 0.
Implementations
sourceimpl ErrorCounter
impl ErrorCounter
sourcepub fn dropped_lines(&self) -> usize
pub fn dropped_lines(&self) -> usize
Returns the number of log lines that have been dropped.
If the non-blocking writer is not configured in lossy mode, the error count should always be 0.